@@ -42,6 +42,21 @@ class TestFuncFinderGetNodeQualName:
                 ['Some.for_test'],
                 id="Async methods"
             ),
+            pytest.param(
+                dedent("""\
+                        def some_decor(f):
+                            def wrapper(*args, **kwargs):
+                                f(*args, **kwargs)
+                            return wrapper
+                            
+                        class Some:
+                            @some_decor
+                            def for_test(self):
+                                pass
+                        """),
+                ['some_decor', 'Some.for_test'],
+                id="Support for decorators"
+            ),
             pytest.param(
                 dedent("""\
                         class Some:
